#%%global  checkout   4118b929da7a7377a32124af72d612be5ac54032
#%%global  date       20151126

Name:    antimony
Summary: Computer-aided design CAD tool
Version: 0.9.1
Release: 0.1%{?dist}
License: MIT
URL:     http://www.mattkeeter.com/projects/antimony/3/
Source0: https://github.com/mkeeter/antimony/archive/%{version}c.tar.gz#/%{name}-%{version}c.tar.gz

##Set path where antimony can find node files
Patch0: %{name}-fix_install_paths.patch

## Main building
BuildRequires: qt5-qtbase-devel
BuildRequires: desktop-file-utils
BuildRequires: boost-python3-devel
BuildRequires: python3-devel
BuildRequires: lemon
BuildRequires: flex
BuildRequires: libpng-devel

%if 0%{?fedora}
BuildRequires: libappstream-glib
%endif

%description
Antimony is a computer-aided design (CAD) tool from a
parallel universe in which CAD software evolved
from Lisp machines rather than drafting tables.

Antimony provides the Python3 Fab that is
a set of software tools for personal fabrication,
intended for use with machines common to fab labs.
For info about Fab visit kokompe.cba.mit.edu/.

%prep
%autosetup -p0 -n %{name}-%{version}c

# Extract the LICENSE
grep "## License" -A 25 README.md | tail -n 25 > LICENSE

%build
mkdir build && cd build
qmake-qt5 -makefile ../sb.pro \
%if 0%{?fedora} < 23
 QMAKE_CFLAGS="$RPM_OPT_FLAGS -Wl,-z,relro -fPIC -pie -Wl,-z,now" \
 QMAKE_CXXFLAGS="$RPM_OPT_FLAGS -Wl,-z,relro -fPIC -pie -Wl,-z,now $(python%{python3_version}-config --includes)" \
 QMAKE_LFLAGS="$RPM_LD_FLAGS -fPIC -pie -Wl,-z,now $(python%{python3_version}-config --ldflags) -L%{_libdir} -lboost_python3"
%else
 QMAKE_CFLAGS="$RPM_OPT_FLAGS" \
 QMAKE_CXXFLAGS="$RPM_OPT_FLAGS $(python%{python3_version}-config --includes)" \
 QMAKE_LFLAGS="$RPM_LD_FLAGS $(python%{python3_version}-config --ldflags) -L%{_libdir} -lboost_python3"
%endif

make %{?_smp_mflags}

%install
#make -C build install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{python3_sitelib}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/Antimony
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/Antimony

install -pm 755 build/app/antimony $RPM_BUILD_ROOT%{_bindir}
cp -a build/app/sb/fab $RPM_BUILD_ROOT%{python3_sitelib}
cp -a build/app/sb/nodes $RPM_BUILD_ROOT%{_datadir}/Antimony
install -pm 644 deploy/icon.svg $RPM_BUILD_ROOT%{_datadir}/icons/Antimony/%{name}.svg

##Make a .desktop file
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Type=Application
Version=1.0
Name=Antimony
Comment=Tree-based Modeler
GenericName=CAD Application
Exec=antimony %f
Icon=%{_datadir}/icons/Antimony/%{name}.svg
Terminal=false
Categories=Graphics;Science;Engineering;
MimeType=application/x-extension-sb;application/x-antimony;
StartupWMClass=antimony
EOF

# Register as an application to be visible in the software center
#
# See http://www.freedesktop.org/software/appstream/docs/ for more details.
# Based on a Richard Hughes appdata file created for Firefox on Fedora
mkdir -p $RPM_BUILD_ROOT%{_datadir}/appdata
cat > $RPM_BUILD_ROOT%{_datadir}/appdata/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2015 Matthew Keeter <jmatt.j.keeter@gmail.com> -->
<component type="desktop">
  <id type="desktop">antimony.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <name>antimony</name>
  <project_license>MIT</project_license>
  <summary>Computer-aided design CAD tool</summary>
  <categories>
   <category>Graphics</category>
   <category>Science</category>
  </categories>
  <description>
    <p>
      Antimony is a computer-aided design (CAD) tool from a
     parallel universe in which CAD software evolved
     from Lisp machines rather than drafting tables.
    </p>
    <p>
     Antimony provides the Python3 Fab that is
     a set of software tools for personal fabrication,
     intended for use with machines common to fab labs.
     For info about Fab visit kokompe.cba.mit.edu/.
    </p>  
  </description>
  <url type="homepage">http://www.mattkeeter.com/projects/antimony/3/</url>
  <screenshots>
    <screenshot type="default">https://sagitter.fedorapeople.org/antimony-screenshots/antimony1.png</screenshot>
    <screenshot>https://sagitter.fedorapeople.org/antimony-screenshots/antimony2.png</screenshot>
    <screenshot>https://sagitter.fedorapeople.org/antimony-screenshots/antimony3.png</screenshot>
  </screenshots>
  <updatecontact>jmatt.j.keeter_at_gmail.com</updatecontact>
</component>
EOF

%post
/bin/touch --no-create %{_datadir}/icons/Antimony &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/Antimony &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/Antimony &>/dev/null || :
fi
/usr/bin/update-desktop-database &> /dev/null || :

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/Antimony &>/dev/null || :

%check
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop
%if 0%{?fedora}
appstream-util validate-relax --nonet $RPM_BUILD_ROOT%{_datadir}/appdata/*.appdata.xml
%endif

%files
%{!?_licensedir:%global license %doc}
%doc README.md doc/*.md
%license LICENSE
%{_bindir}/antimony
%{python3_sitelib}/fab/
%{_datadir}/Antimony/
%{_datadir}/icons/Antimony
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Mon May 23 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.9.1-0.1
- Update to 0.9.1 (pre-release)

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.0-0.7.20151126git4118b9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 23 2016 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.6.20151126git4118b9
- Rebuild for Boost-1.60
- Update to commit #4118b9

* Sun Nov 15 2015 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.5.20151111git12e9f8
- Fixed link to the Python3 library

* Thu Nov 12 2015 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.4.20151111git12e9f8
- Update to commit #12e9f8

* Thu Nov 12 2015 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.3.20151031git5c144c
- Fixed appdata file
- Removed Python3 Provides macro
- Used %%autosetup macro

* Fri Nov 06 2015 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.2.20151031git5c144c
- Update to commit #c144cc
- Hardened build on Fedora 22
- Added an appdata file

* Tue Aug 11 2015 Antonio Trande <sagitter@fedoraproject.org> - 0.9.0-0.1.20150811gitf389cb
- First package
